# Credits

## Development Lead

  - Vito Zanotelli <vito.zanotelli@uzh.ch>
  - Anton Rau <anton.rau@uzh.ch>

## Contributors

  - Jonas Windhager <jonas.windhager@uzh.ch>

None yet. Why not be the first?
